<?php
/**
 * Plugin Name: One Sport - Route Map
 * Plugin URI: http://www.onesportevent.com/get-free-mapping-tool-for-your-website/
 * Description: Display peoples favourite mapped routes from a shared database and allow creation of new maps and routes
 * Author: sporty - sport@onesportevent.com
 * Author URI: http://www.onesportevent.com/about-us
 * Version: 1.6
 * 
 * CHANGELOG
 * 1.0   - Initial version
 * 1.1   - Improved admin screen - reminder message added so people know they have to click 'create page'
 * 1.2   - Improved flexibility - ability to adjust path to mapping component, bing map keys, border control
 * 1.3   - Added ability to map new route
 * 1.4   - Included css and images in package, made default theme more compatible
 * 1.5   - Added partner message
 * 1.6   - Admin and installation fixes, added clean uninstall
 */

/**
* prevent file from being accessed directly
*/
if ('onesportroute.php' == basename($_SERVER['SCRIPT_FILENAME'])) {
	die ('Please do not access this file directly. Thanks!');
}

/**
* Load Includes files
*/
if(!defined('TAMIL_ONESPORTROUTE_PATH')) {
	define('TAMIL_ONESPORTROUTE_PATH', dirname(__FILE__) . "/");
}

if( !class_exists('OneSportRoute') )
{
	class OneSportRoute {
		var $error;
		var $message;

		function __construct($post_id = '') { //constructor

			// Plugin Activation
			add_action('activate_one-sport-route-mapper/onesportroute.php', array(&$this, 'install'));

			// Add header includes
			add_action('init', array($this, 'init'));
			add_action('wp_head', array($this, 'wp_head'));

			// Add the admin menu
			add_action('admin_menu', array($this, 'onesportroute_menu'));
			$this->error = '';
			$this->message = '';
		}

		function __destruct() {
			// Nothing to do...
		}

		function install() {
			$settings = array();
			$settings['includeCrumb'] = 1;
			$settings['borders'] = 0;
			$settings['includeAreas'] = 1;
			$settings['mapHeight'] = '600px';
			$settings['mapWidth'] = '90%';
			$settings['groupBreak'] = 6;
			$this->saveSettings($settings);
		}

		function init() {
			wp_enqueue_script('jquery');
		}

		function wp_head() {
			if (is_feed()) {
				return;
			}

			$settings = array();
			$this->getSettings($settings);

			$list = explode(',', $settings['postId']);
			if((!is_page($list)) && (!is_single($list))) { return; }

			echo "<!-- OneSportEvent Routes Plugin - stylesheet and API link. -->\n";
			if($settings['stylesheet'] != '') {
				echo "<link rel='stylesheet' href='" . $settings['stylesheet'] . "' type='text/css' media='screen' />\n";
			}

			$optional_parameters_boolean = array('includeCrumb','includeAreas', 'borders');
			$optional_parameters_integer = array('pageNo', 'perPage', 'groupBreak');
			$optional_parameters = array('afterDate','keyWord', 'clubID', 'pathAdjust', 'mapKey', 'backgroundColor', 'logo', 'mapHeight', 'mapWidth');

			$optional_string = '';

			foreach($optional_parameters_boolean as $param) {
				$optional_string .= $param . (($settings[$param]) ? " : true" : " : false") . ", ";
			}
			foreach($optional_parameters_integer as $param) {
				if($settings[$param] != '') {
					$optional_string .= $param . " : " . $settings[$param] . ", ";
				}
			}
			foreach($optional_parameters as $param) {
				if($settings[$param] != '') {
					$optional_string .= $param . " : '" . $settings[$param] . "', ";
				}
			}

			if($settings['oseAreaLevel'] != '') {
				$optional_string .= "oseAreaLevel : '" . $settings['oseAreaLevel'] . "', oseAreaID : ". $settings['oseAreaID'];
			} else {
				$optional_string = substr($optional_string, 0, -2);
			}

			if($settings['partnerMsg'] != '') {
				$optional_string .= ", partnerMsg : '" . $settings['partnerMsg'] . "' ";
			}

			if($settings['extraParam'] != '') {
				$optional_string .= ", " . $settings['extraParam'];
			}

			echo "<script type='text/javascript' src='".$settings['path']."?WebKey=".$settings['WebKey']."'></script>\n";
			echo "<script type='text/javascript'>\n";
			echo "jQuery(document).ready(function($){";
			echo '  oseInitRoutes({'.$optional_string.'});// do stuff'."\n";
			echo "});";

			echo "</script>\n";
			echo "<!-- /OneSportEvent Routes Plugin - stylesheet and API link. -->\n";
		}

		function onesportroute_menu() {

			add_submenu_page('options-general.php', 'One Sport Routes' ,'One Sport Routes', '10', __FILE__, array($this, 'manageSettings'));
		}

		function getSettings(&$settings) {
			$settings = unserialize(get_option('onesportroute_settings'));
			// Default Values
			if($settings['path'] == '') {
				$settings['path'] = 'http://api.onesportevent.com/api/routes/v2/RoutesAPI.aspx';
			}
			if($settings['stylesheet'] == '') {
				$settings['stylesheet'] = 'http://api.onesportevent.com/api/style/v1/css/osestyle.css';
			}

			if($settings['pathAdjust'] == '') {
				$settings['pathAdjust'] = 'http://api.onesportevent.com/ClientBin/FitMapper.xap';
			}

			return;
		}

		function saveSettings(&$settings) {
			update_option('onesportroute_settings', serialize($settings));
			return;
		}

		function getAreaLevelList($selected) {
			$list = Array('Auto' => '', 'Country' => 'countryID', 'Region' => 'regionID', 'City' => 'cityID');
			$output = '<select name="oseAreaLevel">'."\n";
			foreach($list as $key => $item ) {
				$output .= '<option value="'.$item.'"';
				$output .= ($selected == $item) ? ' selected' : '';
				$output .= '>'.$key.'</option>'."\n";
			}
			$output .= '</select>';
			return $output;
		}
		function create_page(){
			
			$settings = array();
			$this->getSettings($settings);
			$findme   = 'id="oseRouteCanvas"';
			$page_set = 0;
			
			$page_data = get_page( $settings['postId'] );	// Get page info
			$content = $page_data->post_content;			// Get content
			$pos = strpos($content, $findme);				// Search content for placeholder

			if ($pos > 0) {
			}
			else
			{
				// You can also see a <a href='http://onesportevent.com/api/event/video'>video</a> on how to configure the optional parameters
					echo "<div id='message' class='updated fade'>
						  <p><b>OneSportRoutes is installed</b>.  You'll need to <a href='options-general.php?page=one-sport-route-mapper/onesportroute.php'>go to the configuration</a>, <strong>create a page</strong> and configure any optional parameters before your routes will display on your website.  Please email sport@onesportevent.com if you can't get the routes styling looking how you want it, or to request new features.</p></div>";
			}
		}

		function manageSettings() {

			// Variables
			$base_name = plugin_basename('one-sport-route-mapper/onesportroute.php');
			$base_page = 'admin.php?page='.$base_name;

			$settings = array();
			$this->getSettings($settings);

			$autosave = false;
			// Place below getSettings purposefully.
			if(!empty($_POST['create'])) {
				$title = 'Cool Routes';
				$content = '<div id="oseRouteCanvas"><!-- This is the route placeholder, do not remove this tag --></div>';
				$type = 'page';
		        $post_id = wp_insert_post(array(
					'post_type'		=> $type,
        		    'post_title'    => $title,
		            'post_content'  => $content,
		            'post_status'   => 'publish',
		        ));	
				if($post_id > 0) {
					$post_list = array();
					$post_list = explode(',', $_POST['postId']);
					$post_list[] = $post_id;
					$post_list = array_filter(array_unique($post_list));
					$settings['postId'] = implode(',', $post_list);
					$this->message = 'One Sport Event - Routes page created and settings saved successfully';
				}
				$autosave = true;
			}

			// Form Processing
			if(!empty($_POST['save']) || $autosave) {
				if(!$autosave) {
					$settings['postId'] = $_POST['postId'];
					$this->message = 'Settings saved successfully...';
				}
				$settings['WebKey'] = $_POST['WebKey'];
				$settings['stylesheet'] = $_POST['stylesheet'];
				$settings['pathAdjust'] = $_POST['pathAdjust'];
				$settings['path'] = $_POST['path'];
				$settings['oseAreaLevel'] = $_POST['oseAreaLevel'];
				$settings['oseAreaID'] = $_POST['oseAreaID'];
				$settings['clubID'] = $_POST['clubID'];
				$settings['mapHeight'] = $_POST['mapHeight'];
				$settings['mapWidth'] = $_POST['mapWidth'];
				$settings['afterDate'] = $_POST['afterDate'];
				$settings['pageNo'] = $_POST['pageNo'];
				$settings['includeCrumb'] = ($_POST['includeCrumb'] == 'on') ? 1 : 0;
				$settings['includeAreas'] = ($_POST['includeAreas'] == 'on') ? 1 : 0;
				$settings['borders'] = ($_POST['borders'] == 'on') ? 1 : 0;
				$settings['perPage'] = $_POST['perPage'];
				$settings['keyWord'] = $_POST['keyWord'];
				$settings['logo'] = $_POST['logo'];
				$settings['backgroundColor'] = $_POST['backgroundColor'];
				$settings['mapKey'] = $_POST['mapKey'];
				$settings['extraParam'] = $_POST['extraParam'];
				$settings['partnerMsg'] = $_POST['partnerMsg'];
				$settings['groupBreak'] = $_POST['groupBreak'];
				$this->saveSettings($settings);
			}

			if(!empty($this->message)) { echo '<!-- Last Message --><div id="message" class="updated fade"><p style="color:green;">'.stripslashes($this->message).'</p></div>'; } else { echo '<div id="message" class="updated" style="display: none;"></div>'; }
?>
			<form action="<?php echo htmlspecialchars($_SERVER['REQUEST_URI']); ?>" method="post">
				<div class="wrap">
					<h2>One Sport Event - Routes WebKey</h2>
					<br class="clear" />
					<table class="form-table">
						<tr>
							<th width="20%" scope="row" valign="top">Your API WebKey</th>
							<td width="80%"><input name="WebKey" type="text" value="<?php echo $settings['WebKey'];?>"  size="60"/><a href="http://www.onesportevent.com/get-widget-key" title="Get Webkey" style="text-decoration:none;font-weight:bold;margin-left:10px;" target="_blank">Get Webkey</a></td>
						</tr>
						<tr>
							<th width="20%" scope="row" valign="top">Your BING May Key (optional, but awesum looking maps!)</th>
							<td width="80%"><input name="mapKey" type="text" value="<?php echo $settings['mapKey'];?>"  size="60"/><a href="http://www.bingmapsportal.com/ " title="Get BING Key from Microsoft" style="text-decoration:none;font-weight:bold;margin-left:10px;" target="_blank">Get BING key from Microsoft</a></td>
						</tr>
						<tr>
							<th width="20%" scope="row" valign="top">OneSportRoute API Url</th>
							<td width="80%"><input name="path" type="text" value="<?php echo $settings['path'];?>"  size="60"/></td>
						</tr>
						<tr>
							<th width="20%" scope="row" valign="top">Stylesheet for branding your routes</th>
							<td width="80%"><input name="stylesheet" type="text" value="<?php echo $settings['stylesheet'];?>"  size="60"/></td>
						</tr>
						<tr>
							<th width="20%" scope="row" valign="top">Path to mapping component (adv only)</th>
							<td width="80%"><input name="pathAdjust" type="text" value="<?php echo $settings['pathAdjust'];?>"  size="60"/></td>
						</tr>
					</table>
					<h2>One Sport Routes - Create new page to show routes</h2>
					<br class="clear" />
					<p style="margin-left:1em;">
						<input type="submit" name="create" value="Create New Route Page" class="button" />
					</p>
					<?php if($settings['postId'] != '') { ?>
					<table class="form-table">
						<tr>
							<th width="30%" scope="row" valign="top">Enable API on pages/posts with ID<br/><small style="color:red;">Please ignore this if you are not sure what this is!</small></th>
							<td width="70%"><input name="postId" type="text" value="<?php echo $settings['postId'];?>"  size="20"/></td>
						</tr>
					</table>
					<?php } ?>
					<h2 style="float:left;">Optional Parameters</h2><a href="http://www.onesportevent.com/route-mapping-api-documentation/" title="Visit configuration documentation" style="float:left; font-weight:bold; margin-top:25px; text-decoration:none;" target="_blank">Visit configuration documentation</a>
					<table class="form-table">
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Map height</th>
							<td width="70%"><input name="mapHeight" type="text" value="<?php echo $settings['mapHeight'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Map width</th>
							<td width="70%"><input name="mapWidth" type="text" value="<?php echo $settings['mapWidth'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Display map borders</th>
							<td width="70%"><input name="borders" type="checkbox" <?php echo ($settings['borders']) ? "checked" : "";?> /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Select Area Level<br/><small>If set to Auto, Area ID will be ignored</small></th>
							<td width="70%"><?php echo $this->getAreaLevelList($settings['oseAreaLevel']);?></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Enter Area ID<br/><small>(CountryID, CityID or RegionID you wish to default the view to)</small></th>
							<td width="70%"><input name="oseAreaID" type="text" value="<?php echo $settings['oseAreaID'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Enter Club ID<br/><small>show routes just for a specific club (email us for your clubid)</small></th>
							<td width="70%"><input name="clubID" type="text" value="<?php echo $settings['clubID'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Get routes only after the specified date.<br/><small>e.g. '1-jan-09' - Use dd-MMM-yy format so there is no confusion</small></th>
							<td width="70%"><input name="afterDate" type="text" value="<?php echo $settings['afterDate'];?>" /></td>
						</tr>  
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Request a specific page number (integer).<br/><small>e.g. 3 - Displays the 3rd page</small></th>
							<td width="70%"><input name="pageNo" type="text" value="<?php echo $settings['pageNo'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Display the crumb</th>
							<td width="70%"><input name="includeCrumb" type="checkbox" <?php echo ($settings['includeCrumb']) ? "checked" : "";?> /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Include the areas</th>
							<td width="70%"><input name="includeAreas" type="checkbox" <?php echo ($settings['includeAreas']) ? "checked" : "";?> /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Number of records per page to display (integer).<br/><small>Maxium 15.  By default 10 records per page are shown</small></th>
							<td width="70%"><input name="perPage" type="text" value="<?php echo $settings['perPage'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Number areas to display across the page<br/><small>Suggest 6, and probably at least 2</small></th>
							<td width="70%"><input name="groupBreak" type="text" value="<?php echo $settings['groupBreak'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">ARGB Background colour<br/><small>e.g. #F7FF0000 (alpha, red, green, blue)</small></th>
							<td width="70%"><input name="backgroundColor" type="text" value="<?php echo $settings['backgroundColor'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Your logo embedded in Mapper<br/><small>only available on request</small></th>
							<td width="70%"><input name="logo" type="text" value="<?php echo $settings['logo'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Search for a single keyword.<br/><small>e.g. 'muddy' - All routes with 'muddy' in the name</small></th>
							<td width="70%"><input name="keyWord" type="text" value="<?php echo $settings['keyWord'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Parter Message<br/><small>Appears on email if visitor saves route</small></th>
							<td width="70%"><input name="partnerMsg" type="text" style="width: 500px;" value="<?php echo $settings['partnerMsg'];?>" /></td>
						</tr>
						<!--
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;"Disable parter email<br/><small>(not yet implimented in beta).</small></th>						<!--Turns of automated email when route saved-->
							<td width="70%"><input name="disablePartner" type="text" value="<?php echo $settings['disablePartner'];?>" /></td>
						</tr>
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;"Generate revenue<br/><small>(not yet implimented in beta).</small></th>						
							<td width="70%"><input name="generateRevenue" type="text" value="<?php echo $settings['generateRevenue'];?>" /></td>
						</tr>
						-->
						<tr>
							<th width="30%" scope="row" valign="top" style="text-align:right;">Additional Parameter(s) string.<br/><small>Leave it blank if you are not sure</small></th>
							<td width="70%"><input name="extraParam" type="text" value="<?php echo $settings['extraParam'];?>" /></td>
						</tr>
					</table>
					<p style="text-align: center;">
						<input type="submit" name="save" value="Save Settings" class="button" />&nbsp;&nbsp;
						<input type="button" name="cancel" value="Cancel" class="button" onclick="javascript:history.go(-1)" />
					</p>
				</div>
			</form>
<?php 

		}

	}// END Class OneSportRoute
}

// Run The Plugin!
if( class_exists('OneSportRoute') ){
	$routes = new OneSportRoute();
	add_action( 'admin_notices', array($routes,'create_page') );
}

?>